/////////////////////////////////////////////////////////////////////////////////////////
// Jocopod -- Joystick to Control Port Dongle
//            --          --      --   -
//
// (c) 2015-2016, Oliver "lvr" Tscherwitschke
// lvr@bitbang.de
//
// This file is part of the Jocopod Firmware.
//
// The Jocopod Firmware is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// The Jocopod Firmware is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Jocopod Firmware. If not, see <http://www.gnu.org/licenses/>.
/////////////////////////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////////////////////////
// Include files

#include <Arduino.h>
#include <EEPROM.h>

#include "eedata.h"
#include "main.h"

////////////////////////////////////////////////////////////////////////////
// Check the EEPROM contents for consistency and read it to global variables
int eepromRead(void)
{
    // Check if EEPROM data is consistent
    if (EEPROM[offsetof(EepromData, guard1)] != EEPROM[offsetof(EepromData, guard2)])
        return EE_GUARD_ERROR;

    if (EEPROM[offsetof(EepromData, structVersion)] != EEPROM_STRUCT_VERSION)
        return EE_VERSION_ERROR;

    // Data seems to be consistent, so read it
    EEPROM.get(offsetof(EepromData, operatingMode), operatingMode);
    EEPROM.get(offsetof(EepromData, x), axisX);
    EEPROM.get(offsetof(EepromData, y), axisY);

    return EE_OK;
}


////////////////////////////////////////////////////////////////////////////
// Write current values of gloabal variables to EEPROM
int eepromWrite(void)
{
    uint8_t guard;

    // Increment 'guard' value by one
    guard = EEPROM[offsetof(EepromData, guard1)] + 1;
    EEPROM[offsetof(EepromData, guard1)] = guard;

    // Structure version
    EEPROM.put(offsetof(EepromData, structVersion), EEPROM_STRUCT_VERSION);

    // Write payload
    EEPROM.put(offsetof(EepromData, operatingMode), operatingMode);
    EEPROM.put(offsetof(EepromData, x), axisX);
    EEPROM.put(offsetof(EepromData, y), axisY);
    
    EEPROM[offsetof(EepromData, guard2)] = guard;
    return EE_OK;
}



