/////////////////////////////////////////////////////////////////////////////////////////
// Jocopod -- Joystick to Control Port Dongle
//            --          --      --   -
//
// (c) 2015-2016, Oliver "lvr" Tscherwitschke
// lvr@bitbang.de
//
// This file is part of the Jocopod Firmware.
//
// The Jocopod Firmware is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// The Jocopod Firmware is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Jocopod Firmware. If not, see <http://www.gnu.org/licenses/>.
/////////////////////////////////////////////////////////////////////////////////////////

#ifndef IO_H
#define IO_H


/////////////////////////////////////////////////////////////////////////////////////////
// Pin definitions

//
//                  +-\/-+
//            PC6  1|    |28  PC5 (AI 5) / (D 19)
//      (D 0) PD0  2|    |27  PC4 (AI 4) / (D 18)
//      (D 1) PD1  3|    |26  PC3 (AI 3) / (D 17)
//      (D 2) PD2  4|    |25  PC2 (AI 2) / (D 16)
// PWM+ (D 3) PD3  5|    |24  PC1 (AI 1) / (D 15)
//      (D 4) PD4  6|    |23  PC0 (AI 0) / (D 14)
//            VCC  7|    |22  GND
//            GND  8|    |21  AREF
//            PB6  9|    |20  AVCC
//            PB7 10|    |19  PB5 (D 13)
// PWM+ (D 5) PD5 11|    |18  PB4 (D 12)
// PWM+ (D 6) PD6 12|    |17  PB3 (D 11) PWM
//      (D 7) PD7 13|    |16  PB2 (D 10) PWM
//      (D 8) PB0 14|    |15  PB1 (D 9)  PWM
//                  +----+
//
// (PWM+ indicates the additional PWM pins on the ATmega168.)




#define DPIN_LED1               13
#define DPIN_LED2               1   // also TXD

#define DPIN_CALIB2             0   // also RXD


// The analog pins of the analog joystick
#define APIN_JOY1X              0
#define APIN_JOY1Y              1
#define APIN_JOY2X              6
#define APIN_JOY2Y              7


// The digital pins of the analog joystick
#define DPIN_JOYBTN1            16
#define DPIN_JOYBTN2            17
#define DPIN_JOYBTN3            18
#define DPIN_JOYBTN4            19


// Pins for paddle simulation
#define DPIN_PADDLE_PULSE_X     9   // Used as output compare output
#define DPIN_PADDLE_FULL_X      8

#define DPIN_PADDLE_PULSE_Y     10  // Used as output compare output
#define DPIN_PADDLE_FULL_Y      11


#define DPIN_DISCHARGE_DETECT   6   // Used for analog comparator AIN0
#define DPIN_DISCHARGE_THRESH   7   // Used for analog comparator AIN1


// Output pins for digital joystick
#define DPIN_JOY_UP             5
#define DPIN_JOY_DOWN           4
#define DPIN_JOY_LEFT           3
#define DPIN_JOY_RIGHT          2
#define DPIN_JOY_FIRE           12


#endif

